Agents
====================
This module implements the fitted Q-iteration algotithm for offline reinforcement learning.

.. code:: python

   from pycfrl import agents

.. automodule:: pycfrl.agents
   :members:
   :show-inheritance:
   :special-members: __init__